#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 21/08/2009
#
#package			: superkart
#homepage			: http://supertuxkart.sourceforge.net/
#source location	: http://ovh.dl.sourceforge.net/sourceforge/supertuxkart/supertuxkart-0.6.2-src.tar.bz2
#dependency         : 

softname='supertuxkart'
softversion='0.6.2'
packageversion='62.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/"$softname-$softversion"-src.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://ovh.dl.sourceforge.net/sourceforge/supertuxkart/"$softname-$softversion"-src.tar.bz2

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
            |-----handy-ruler------------------------------------------------------|
supertuxkart: supertuxkart - A Free 3D kart racing game
supertuxkart:
supertuxkart: SuperTuxKart is a Free 3d kart racing game; we want to make the game
supertuxkart: fun more than we want to make it realistic. You can play with up to
supertuxkart: 4 friends on one PC, racing against each other or just try to 
supertuxkart: beat the computer. (a network multiplayer feature is under  
supertuxkart: development)
supertuxkart: 
supertuxkart: 
supertuxkart: 
supertuxkart:
EOF

#
# Verifie si package est present
#
if [ -f "$softname-$softversion"-src.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xjvf $srcpkg
cd $src	

#
# "faire" le package package
#
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"


./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--exec-prefix="/usr" \
	--bindir="/usr/bin" \
	--sysconfdir="/etc" \
	--datadir="/usr/share" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

#
# "faire" le package package
#
make $numjobs DESTDIR=$dest

#
# installer le package dans son répertoire de destination
#
make install DESTDIR=$dest

mv $dest/usr/games/supertuxkart $dest/usr/bin
rm -rf $dest/usr/games/

#
# faire le fichier .desktop
#
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Supertuxkart
Version=0.5
Icon=supertuxkart
Comment=A kart racing game
Comment[fr_FR]=Un jeu de karting
Comment[ro_RO]=Un joc de curse cu carturi
Comment[de_DE]=Ein Kart-Rennspiel
Exec=supertuxkart
Terminal=false
StartupNotify=false
Type=Application
Categories=Game;ArcadeGame
EOF
   
cp ../supertuxkart.png  $dest/usr/share/icons/hicolor/48x48/apps
   
#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      NEWS COPYING INSTALL TODO AUTHORS ChangeLog README \
      $dest/usr/doc/$softname-$softversion
    rm -rf $dest/usr/share/doc
	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.txz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.txz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "cxxlibs,e2fsprogs,gcc,gcc-g++,libdrm,libogg,libvorbis,mesa,openal,sdl,xcb,xorg-libs" > $package.dep

#
# produire le fichier source
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/supertuxkart/source/build-supertuxkart.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/supertuxkart/source/supertuxkart.png >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
